CREATE OR REPLACE FORCE EDITIONABLE VIEW "AROPS"."SOD_CASE_V" ("ID", "STATE", "POLICY", "VIOLATOR_IS_USER", "VIOLATOR_NAME", "VIOLATOR_TITLE", "POLICY_NAME", "LAST_ACTION", "LAST_ACTION_COMMENT", "LAST_ACTION_TIME", "LAST_PERFORMED_BY", "INITIAL_DETECTED", "LATEST_DETECTED", "COUNT_DETECTED", "COUNT_ACTIONS", "CONTROL_PERIOD", "CREATED_BY") AS 
 SELECT sci.id,
    sci.state,
    sci.policy,
    sci.violator_is_user,
    sci.violator_name,
    sci.violator_title,
    sci.policy_name,
    sca1.action last_action,
    sca1.action_comment last_action_comment,
    sca1.action_time last_action_time,
    sca1.performed_by last_performed_by,
    ( SELECT min(sod_violation.detected_time) min
           FROM sod_violation
          WHERE (sod_violation.sod_case = sci.id)) initial_detected,
    ( SELECT max(sod_violation.detected_time) max
           FROM sod_violation
          WHERE (sod_violation.sod_case = sci.id)) latest_detected,
    (SELECT count(sod_violation.id) count
           FROM sod_violation
          WHERE sod_violation.sod_case = sci.id AND
          EXISTS (SELECT 1 FROM snapshot sn
            JOIN snapshot_sversions snsv on snsv.snapshot = sn.id
            WHERE snsv.sversions = sod_violation.sversion AND
            sn.type = 'PUBLICATION' AND
            sn.status = 'REALIZED')) count_detected,
    ( SELECT count(sod_case_action.id) count
           FROM sod_case_action
          WHERE (sod_case_action.sod_case = sci.id)) count_actions,
    sod_policy.control_period,
    suser.display_name created_by
   FROM (((sod_case_info sci
     LEFT JOIN sod_case_action sca1 ON ((sca1.sod_case = sci.id)))
     JOIN sod_policy ON ((sod_policy.id = sci.policy)))
     LEFT JOIN suser ON (((((sod_policy.created_by) = (suser.unique_user_id)) AND (suser.deleted = '0')) AND (suser.effective = '1'))))
  WHERE ((sca1.action_time IN ( SELECT max(sca2.action_time) max
           FROM sod_case_action sca2
          WHERE (sca2.sod_case = sci.id))) OR (sca1.action_time IS NULL))
  ORDER BY sci.id;